==> aar_multi_chip-1.1.216-sources.jar: com/xdja/multichip/process/cardstatus/CardStatusProvider.java <==
package com.xdja.multichip.process.cardstatus;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;


import com.xdja.multichip.process.MainProcessStartUpReceiver;

import static com.xdja.multichip.param.ParamKeywords.KEY_Binder_Binder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_CardStatusBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_GetBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_int_ret;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CardStatusProvider extends ContentProvider {

    @Override
    public boolean onCreate() {
        CardStatusBinderService.getInstance(getContext());
        MainProcessStartUpReceiver.sendMainProcessStartUpEvent(getContext());
        return false;
    }


    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
        return null;
    }


    @Override
    public String getType(Uri uri) {
        return null;
    }


    @Override
    public Uri insert(Uri uri, ContentValues values) {
        return null;
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        return 0;
    }


    @Override
    public Bundle call(String method, String arg, Bundle extras) {
        if (KEY_METHOD_GetBinder.equals(method) && KEY_METHOD_CardStatusBinder.equals(arg)) {
            Bundle result = new Bundle();
            result.putInt(KEY_int_ret, 0);
            result.putBinder(KEY_Binder_Binder, CardStatusBinderService.getInstance(getContext()).asBinder());
            return result;
        }
        return super.call(method, arg, extras);
    }
}

==> aar_multi_chip-1.2.10-sources.jar: com/xdja/multichip/process/cardstatus/CardStatusProvider.java <==
package com.xdja.multichip.process.cardstatus;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;

import static com.xdja.multichip.param.ParamKeywords.KEY_Binder_Binder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_CardStatusBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_METHOD_GetBinder;
import static com.xdja.multichip.param.ParamKeywords.KEY_int_ret;

/**
 * @author: zhangxiaolong@xdja.com <br/>
 * date:   2018/5/16 <br/>
 */
public class CardStatusProvider extends ContentProvider {

    @Override
    public boolean onCreate() {
        startTheService();
        return false;
    }


    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
        return null;
    }


    @Override
    public String getType(Uri uri) {
        return null;
    }


    @Override
    public Uri insert(Uri uri, ContentValues values) {
        return null;
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        return 0;
    }


    @Override
    public Bundle call(String method, String arg, Bundle extras) {
        if (KEY_METHOD_GetBinder.equals(method) && KEY_METHOD_CardStatusBinder.equals(arg)) {
            Bundle result = new Bundle();
            result.putInt(KEY_int_ret, 0);
            result.putBinder(KEY_Binder_Binder, CardStatusBinderService.getInstance(getContext()).asBinder());
            return result;
        }
        return super.call(method, arg, extras);
    }

    private void startTheService() {
        Intent intent = new Intent();
        intent.setClass(getContext(), CardStatusService.class);
        getContext().startService(intent);
    }
}
